import pytest

from numerous_image_tools.image_test.build import build_image
from numerous_image_tools.image_test.run import run_container

def pytest_namespace():
    return {'image': None}

def test_build_image():

    image = build_image("docker_test_context/.")

    pytest.image = image

def test_run_image():
    run_container(pytest.image)